diff --git a/thunar/thunar-shortcuts-model.c b/thunar/thunar-shortcuts-model.c
index ac482615fe724c289e72b041ce0e33a086521b3b..6a98e9a44b64a24a49d7f481096bf1bb85e9a0f1 100644
--- a/thunar/thunar-shortcuts-model.c
+++ b/thunar/thunar-shortcuts-model.c
@@ -1935,8 +1935,8 @@ thunar_shortcuts_model_drop_possible (ThunarShortcutsModel *model,
   if (shortcut->group == THUNAR_SHORTCUT_GROUP_PLACES_BOOKMARKS)
     return TRUE;
 
-  /* we can drop at the end of the bookmarks (before network header) */
-  if (shortcut->group == THUNAR_SHORTCUT_GROUP_NETWORK_HEADER)
+  /* we can drop at the end of the bookmarks (before devices header) */
+  if (shortcut->group == THUNAR_SHORTCUT_GROUP_DEVICES_HEADER)
     return TRUE;
 
   return FALSE;